#
# spec file for package remmina
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
%bcond_without  remmina_kwallet
%else
%bcond_with     remmina_kwallet
%endif
Name:           remmina
Version:        1.4.39
Release:        1.3
Summary:        Versatile Remote Desktop Client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://www.remmina.org/
Source0:        https://gitlab.com/Remmina/Remmina/-/archive/v%{version}/Remmina-v%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  curl-devel
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  fuse3-devel
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libsodium-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gvnc-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(spice-client-gtk-3.0)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(webkit2gtk-4.1)
%if 0%{?suse_version} > 1690
BuildRequires:  pkgconfig(freerdp3) >= 3.0.0
BuildRequires:  pkgconfig(winpr3)
%else
BuildRequires:  freerdp2-devel < 3.0.0
BuildRequires:  freerdp2-server < 3.0.0
BuildRequires:  pkgconfig(winpr2)
%endif
BuildRequires:  pkgconfig(xkbfile)
Recommends:     %{name}-plugin-rdp
Recommends:     %{name}-plugin-secret
Recommends:     %{name}-plugin-vnc
Provides:       %{name}-plugins-common = %{version}
Obsoletes:      %{name}-plugins-common < 1.0.0
%if %{with remmina_kwallet}
BuildRequires:  cmake(KF5Wallet)
%endif
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(wayland-client)
%endif

%description
Remmina is a remote desktop client written in GTK+, aiming to be useful for
system administrators and travellers, who need to work with lots of remote
computers in front of either large monitors or tiny netbooks. Remmina supports
multiple network protocols such as RDP, VNC, NX, XDMCP and SSH via separate
plugins in an integrated and consistant user interface.

%package kiosk
Summary:        Login manager extension for a Remmina kiosk mode
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description kiosk
This package installs a Remmina Kiosk mode to the list of the
available sessions for all freedesktop compliant login managers.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains header files needed for developing plugins for
Remmina.

%package plugin-exec
Summary:        Plugin for Remmina to allow execution of local commands
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-exec
This package provides a plugin for Remmina allowing the execution of
local commands.

%package plugin-python-wrapper
Summary:        Adapter for remmina Python plugins
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-python-wrapper
This package provides an adapter used by remmina Python plugins

%package plugin-spice
Summary:        SPICE Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-spice
This package provides the SPICE protocol plugin for Remmina.

%if %{with remmina_kwallet}
%package plugin-kwallet
Summary:        Remmina plugin to support the KDE Wallet
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-kwallet
KDE Wallet plugin, that can be used instead of the GNOME Keyring
%endif

%package plugin-rdp
Summary:        RDP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       freerdp
Requires:       remmina = %{version}

%description plugin-rdp
This package provides the RDP protocol plugin for Remmina.

%package plugin-vnc
Summary:        VNC Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-vnc
This package provides the RDP protocol plugin for Remmina.

%package plugin-gvnc
Summary:        VNC Protocol Plugin for Remmina via GTK+ widget
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-gvnc
This package provides the RDP protocol plugin for Remmina using the
VNC viewer widget for GTK+.

%package plugin-www
Summary:        WWW Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-www
This package provides the a plugin for Remmina which allows to login and
to browse a page.

%package plugin-secret
Summary:        Gnome Keyring Pasword Manager Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}
Provides:       remmina-plugins-gnome = %{version}
Obsoletes:      remmina-plugins-gnome < %{version}

%description plugin-secret
This package provides a Remmina plugin for the GNOME keyring password manager.

%lang_package

%prep
%autosetup -p1 -n Remmina-v%{version}
sed -e 's|%{_bindir}/env bash|%{_bindir}/sh|' -i data/desktop/remmina-file-wrapper.in

%build
export LDFLAGS="-pie"
export CFLAGS="%{optflags} -fPIE -pie"
%ifarch aarch64
export CFLAGS="$CFLAGS -fPIC"
%endif

%cmake \
	-DCMAKE_SKIP_RPATH=ON \
	-DWITH_NEWS=OFF \
	-DWITH_KIOSK_SESSION=ON \
	-DWITH_GVNC=ON \
%if 0%{?suse_version} > 1590
  -DWITH_FREERDP3=ON \
%endif
%if %{with remmina_kwallet}
	-DWITH_KF5WALLET=ON \
%else
	-DWITH_KF5WALLET=OFF \
%endif
	-DWITH_APPINDICATOR=ON \
	%{nil}

%cmake_build

%install
%cmake_install

%suse_update_desktop_file org.remmina.Remmina Network RemoteAccess GTK

%fdupes %{buildroot}%{_datadir}/remmina
%fdupes %{buildroot}%{_datadir}/icons

%find_lang %{name}

%files
%license LICENSE LICENSE.OpenSSL
%doc AUTHORS CHANGELOG.md README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-file-wrapper
%{_datadir}/applications/org.remmina.Remmina-file.desktop
%{_datadir}/applications/org.remmina.Remmina.desktop
%dir %{_datadir}/icons/hicolor/apps
%{_datadir}/icons/hicolor/apps/*
%{_datadir}/icons/hicolor/**/**/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.remmina.Remmina.appdata.xml
%{_datadir}/mime/packages/org.remmina.Remmina-mime.xml
%{_datadir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins/
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-file-wrapper.1%{?ext_man}

%files kiosk
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_datadir}/gnome-session/sessions/remmina-gnome.session
%{_bindir}/gnome-session-remmina
%{_bindir}/remmina-gnome
%{_mandir}/man1/gnome-session-remmina.1%{?ext_man}
%{_mandir}/man1/remmina-gnome.1%{?ext_man}
%{_datadir}/xsessions/remmina-gnome.desktop
%{_datadir}/applications/%{name}-gnome.desktop

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files plugin-exec
%{_libdir}/remmina/plugins/remmina-plugin-exec.so

%files plugin-python-wrapper
%{_libdir}/remmina/plugins/remmina-plugin-python_wrapper.so

%files plugin-spice
%{_libdir}/remmina/plugins/remmina-plugin-spice.so

%if %{with remmina_kwallet}
%files plugin-kwallet
%{_libdir}/remmina/plugins/remmina-plugin-kwallet.so
%endif

%files plugin-rdp
%{_libdir}/remmina/plugins/remmina-plugin-rdp.so

%files plugin-vnc
%{_libdir}/remmina/plugins/remmina-plugin-vnc.so

%files plugin-gvnc
%{_libdir}/remmina/plugins/remmina-plugin-gvnc.so

%files plugin-www
%{_libdir}/remmina/plugins/remmina-plugin-www.so

%files plugin-secret
%{_libdir}/remmina/plugins/remmina-plugin-secret.so

%changelog
* Wed Jan  8 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.39:
  * [REM-3260] Fix bug passing wrong value in SPICE plugin (Breaking compilation on some distributions) !2624 @myheroyuki
  * [REM-3257] Add option to automatically copy ssh text when selected !2624 @myheroyuki
  * [REM-2604] Allow -c to work with www plugin !2604 @myheroyuki
  * [REM-3256] Don't prompt about closing connections with no connections !2625 @myheroyuki
  * Mainly fixing memory leaks and some small bugs !2626 @myheroyuki
* Mon Dec 30 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.37:
  * Implement horizontal smooth scrolling in RDP !2606 @acutemeridian
  * [REM-3209] Allow -c to work with www plugin !2607 @myheroyuki
  * [REM-3210] Add ability to lock message panels to one side of the window !2608 @myheroyuki
  * [REM-3223] fix dangling pointer in ssh_options_get_port invocation !2609 @Victrid
  * Revert "[REM-2854] Add timeout option to handle VNC disconnects" !2610 @myheroyuki
  * Fix OpenSSL include dir !2611 @mtelka
  * Revert "[REM-3121] Handle GotFrameBufferUpdate on its own thread to prevent freeze" !2612 @myheroyuki
  * [REM-3227] fix compile warning that is failure with newer gcc versions !2613 @myheroyuki
  * [REM-3206] Add null check to prevent crash when pasting empty clipbaord !2614 @myheroyuki
  * [REM-3076] [REM-3086] Remove support for FreeRDP_SupportMonitorLayoutPdu to prevent loss of keyboard with xrdp !2615 @myheroyuki
  * [REM-3236] Don't rely on padding characters to be present to try decrypting passwords !2616 @myheroyuki
  * [REM-3246] Add option to immediately close VNC windows when they fail to... !2617 @myheroyuki
  * Allow Remmina to use plugins immediately on download without needing a restart !2618 @myheroyuki
  * [REM-3176] Add plugin api to allow Remmina to display if a profile is... !2619 @myheroyuki
  * [REM-3177] Fix error message for failed RDP connection !2620 @myheroyuki
  * Add more detail to bug report to make certain issues easier to solve !2621 @myheroyuki
  * [REM-3176] Resize icons to fit flatpak specifications !2622 @myheroyuki
* Thu Oct 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(webkit2gtk-4.0) with pkgconfig(webkit2gtk-4.1)
  BuildRequires, following this drop conditional
  pkgconfig(libsoup-2.4) BuildRequires, use only libsoup-3.0 going
  forward.
* Thu Oct 10 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.36:
  * Fix crash with keyboard-interactive SSH auth !2576 @bhatman1441
  * Prevent empty remmina_file_name in remmina.pref !2577 @bhatman1441
  * rdp/rdp-plugin: Fix faulty color depth check !2579 @pnowack
  * Fix typos !2578 @deining
  * Usbredirect on connect !2580 @hunderteins
  * [REM-3104] Add global RDP options to set FreeRDP auth filter !2581 @myheroyuki
  * Use universal /bin/sh shebang in remmina-rile-wrapper(1) !2572 @klemensn
  * [REM-3104] Added back in line that was accidentally removed before merge !2582 @myheroyuki
  * [REM-3104] Do not initialize rdp_auth_filter !2583 @myheroyuki
  * [REM-3076] Add proxy field for SPICE connections !2584 @myheroyuki
  * add a conditional check for darwin and NetBSD !2585 @gador1
  * [REM-3103] Make more obvious to user that Remmina may not be able to exec... !2586 @myheroyuki
  * [REM-3121] Handle GotFrameBufferUpdate on its own thread to prevent freeze !2587 @myheroyuki
  * Enable horitical scroll on RDP plugin. !2588 @AkiraPenguin
  * [REM-2854] Add timeout option to handle VNC disconnects !2589 @myheroyuki
  * [REM-3134] Fix bug where option to send clipboard as keystrokes did not appear !2590 @myheroyuki
  * Add ability to send a key combination when RDP connection is idle !2591 @dexxter00
  * [REM-3111] Do not prompt user for credentials if they have already been entered !2592 @myheroyuki
  * [REM-3140] Add null check to prevent segfault !2593 @myheroyuki
  * Move the idle timer into rf_context to make it session-specific. !2594 @morganw3
  * [REM-3156] Limit connection name on rcw tab to reasonable length !2595 @myheroyuki
  * Update several dependencies !2596 @myheroyuki
  * [REM-3127] Add user prompt for gateway messages !2597 @myheroyuki
  * [REM-3167] Add reconnect button to rcw !2598 @myheroyuki
  * [REM-3127] Changed to put call to a message accept panel in the RemminaPluginService struct !2599 @myheroyuki
  * Removed unused, commented code !2600 @myheroyuki
  * [REM-2428] Allow floating toolbar to be drag and dropped to more locations on the screen !2601 @myheroyuki
  * [REM-3162] Fixed some compile warnings causing issues with GCC 14.2.1 !2602 @myheroyuki
  * Update ssh error to not show outdated message !2603 @myheroyuki
* Wed Apr 17 2024 Daike Yu <yu.daike@suse.com>
- Fix dependency on SLE-15-SP6
* Wed Apr  3 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.35 stable release.
* Wed Feb 21 2024 balping314@gmail.com
- Update to version 1.4.34~git.20240221 (boo#1220149):
  * Updated call to set FreeRDP_LoadBalanceInfo
  * Revert setting loadbalanceinfo to the old method used before FreeRDP3
  * Add FreeRDP version to cmake status messages
  * FreeRDP3: Fix crash with disablepasswordstoring enabled
  * [REM-3047] fix issue compiling with gcc-14
  * Check if WINPR_ASSERT is defined
  * Allow running an SSH command when connecting via ssh tunnel
  * Fix build for openssl-1.1
* Thu Jan 25 2024 info@paolostivanin.com
- Update to version 1.4.33~git.20240124:
  * Add support for FreeRDP 3.x
  * Allow Remmina to be built without FreeRDP
  * Made file not empty to allow setting for Service Desk
* Thu Oct 12 2023 Bjørn <bjorn.lie@gmail.com>
- Update to version 1.4.33:
  * Add shortcut for 'send clipboard as keystrokes'
  * Make keeping window open on session disconnect configurable
  * Fix crash cause by using freed memory
* Sun Sep 17 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to remmina version 1.4.32:
  * [REM2916] Added option to kill async process started by
    exec plugin on tab close
  * Fix search bar toggle behavior
  * Fix memory leaks
  * [REM-2920] Password visibility can now be toggled on remmina_message_panels
  * Remove SSH file paths from remmina file when unchecking box in profile edit
  * Solved issue #2910 - Added support for IPv6 with fallback to IPv4 for ssh
  * Fix UI bugs in Remmina Preferences set new password
  * Fix memory leaks and change GTK critical errors to remmina warnings
    for null icon autostart file
  * [REM-2926] Added ability to set a fixed aspect ratio for vnc connections
  * [REM-2936] Fix crash related to unmap events
  * [REM-2938] Improved ordering of tray icon menu items
  * Fix memory leaks in remmina_plugin_manager_init with g_free and g_ptr_array_free
  * Remote assistance
  * Spelling: Various strings for assistance mode
  * Fix some compiler warnings
  * Ability to SPICE connect to unix domain socket
  * update multi monitor icon
  * Save toggle options when duplicating connection
  * New feature: Allow user to specify use of modifiers when changing key preferences
  * [REM-2914] Alert user of unexpected disconnect instead of immediately closing
    the connection window
  * Fix Remmina not using @REMMINA_BINARY_PATH@
  * Highlight top bar when Grab all keyboard events is enabled
  * [REM-2850] Add ability to automatically move mouse to keep RDP connections alive
  * Remove unnecessary parameters from remmina_public_get_server_port_wrapper
  * Fix freeze that occurs when loading in python modules properly
  * [REM-1923] Fix handling of pause break key for RDP connections
  * [REM-2971] When quiting Remmina from the system tray the are you sure
    prompt now functions properly
* Fri Jun  9 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to remmina version 1.4.31:
  * [REM-2874] muli password changer search now matches partial
    strings !2480
  * Fix segfault in VNC when using domain socket !2481
  * Switched pylist Append to SetItem !2482
  * Template texts updated !2484
  * Add menu option to delete multiple profiles at the same time !2483
  * add 1080p as a default resolution to remmina_pref.c !2486
  * Remove character limit on password length !2489
  * Create better postats.html !2488
  * Redesign santahat.png & add santahat.svg !2492
  * Edit preferences UI !2491
  * Change the icon of the new connection button !2493
  * Modify the checkbox of the appearance-tab !2494
  * Add valign to the switch of the debugging window !2495
  * plugins/rdp: Ensure output redirection configuration applies to
    both dynamic and static rdpsnd !2498
* Fri Apr 14 2023 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to remmina version 1.4.30
  * Add text mime type formats to RDP clibpoard !2459
  * Ensure timer is null after destruction !2462
  * Ability to view passwords in the clear using a toggle in the
    password field !2460
  * Made icons viewable in lower resulution. !2463
  * Improve mime file !2464
  * [REM-2809] Appearance preferences now refresh in the main window when
    the user... !2466
  * This should be a message instead of a info print.
    So that the user can see it by default. !2461
  * remmina_rdp_monitor_get(): fix maxw, maxh and monitorids calculation !2467
  * Rem 2864 !2469
  * Fix undefined symbol error when importing gi in a python extension !2470
  * Rem 2864 !2472
  * [REM-1987] allow for dynamic resolution updates for vnc connections !2476
  * Fix overlapping text in preferences menu, terminal tab !2477
  * Allow could not authenticate banner to go away after successful
    reauthentication !2478
  * Add environments for easy manual testing !2473
* Thu Jan 26 2023 ecsos <ecsos@opensuse.org>
- Update to remmina version 1.4.29
  * Hiroyuki Tanaka added to README :) !2451
  * Initial macOS support !2453
  * X2Go error-message consistency !2452
  * Avoid crash when closing, fixes issue #2832 !2454
  * Update Copyright for 2023 !2455
  * Aligning local and downstream jsons !2456
- Update to remmina version 1.4.28
  * Some minor RDP fixes !2415
  * Mathias Winterhalter's avatar Fix Unix socket support for VNC !2417
  * GVNC: Fixed JPEG quality encoding advertizing !2418
  * Fix missing null checks causing signal 11 !2419
  * Add modified date to SFTP file list !2420
  * Adding Labels/Tags !2421
  * Spelling: Hostname !2422
  * X2Go: Fix annoying default_username bug. !2423
  * plugins/x2go/x2go_plugin.c: Fix tip and comment sentence !2424
  * Remove webkit_settings_set_enable_frame_flattening() for newer WekbKitGTK, fixes #2780 !2425
  * Change password including gateway !2427
  * Improve rcw close !2429
  * Multiple changes to build and run with libsoup 3.0 !2431
  * X2Go: Add ssh_passphrase and ssh_privatekey settings. !2428
  * RDP: Add option to disable output suppression !2432
  * Spelling: "Passphrase" → "password" !2433
  * Fix compile warnings and some spelling corrections !2434
  * [Rem-2782] Display protocol name in tooltip for connections in the ... menu... !2436
  * [Rem-2782] Added protocol icons in drop-down menu !2438
  * Fix widget reparenting when entering/exiting fullscreen !2439
  * Rem 2760 !2440
  * Allow building on a Wayland-only environment - version 4 !2437
  * [Rem-2564] Allow for VNC runtime adjustment of color depth !2442
  * Fix floating toolbar not disappearing when in fullscreen and keyboard grabbed !2441
  * Revert "Merge branch 'Rem-2564' into 'master'" !2443
  * [Rem-2654] Allow for runtime adjustment of colour depth, both increasing and decreasing !2444
  * [Rem-2564] Changed declaration of variables to be compatible with different Ubuntu version !2445
  * [Rem-2682] Added view-only mode for RDP !2447
  * Removing the news widget !2446
  * Updated Flatpak manifest files to match GitHub !2448
  * Add missing include for X11/Wayland conditional !2450
- Drop libsoup_2_and_3_support.patch because now in upstream.
* Wed Oct 19 2022 Michael Gorse <mgorse@suse.com>
- Add libsoup_2_and_3_support.patch: support libsoup 3.0
  (boo#1204492).
- Build against libsoup 3 on Tumbleweed.
* Mon Aug  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Set CMAKE_SKIP_RPATH to avoid writing bogus RUNPATH to
  binaries and modules
- Spec cleanup
* Tue Jun 21 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.27
  * Fix dangling pointer after scrolled container destruction.
  * Strengthen remmina file set string
  * Refactoring and minor fixes
  * launcher.sh is compatible with xfce4-terminal and gnome-terminal now.
  * Fix #2473 - revive rcw_focus_out_event to avoid sticky Alt on Alt-TAB
  * New SSH color schemes.
  * Some grammar fixes.
- Removed 2734-flatpak-crash.patch
* Wed Jun  1 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added 2734-flatpak-crash.patch to fix an issue reported on upstream:
  [#2580]: "Closing RDP connection quits Remmina without an error message"
* Tue May 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend lang package: the lang package has smarter
  supplements in place.
* Thu May 19 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.26
- Major improvements:
  * A Python plugin/API (you can write Remmina plugins in Python now!!!)
  * X11 Forward for the SSH plugin @marco.fortina
  * Kiosk improvements and new command lines options
- Other changes:
  * Fix trial for 2577: Closing a VNC connection makes Remmina close all other...
  * Handle after-auth connection errors in VNC properly
  * Using Remmina from command-line for kiosked servers
  * Manual page refactoring fixes #2056 (closed)
  * Add mutex to protect RDP clipboard->srv_data. Fixes #2666 (closed)
  * Add '--no-tray-icon' command-line option
  * Make FreeRDPs TLS Security Level setting accessible in the advanced settings view
  * Disable grabs for SSH and SFTP, #closes #2728 (closed)
  * Cannot disable shared folder
  * Use PyInitializeEx in order to skip signal handler registration
  * Ignore add new connection button in kiosk mode
  * WWW plugin refactoring
* Thu Mar 10 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.25
  * kiosk: Drop GNOME MediaKeys plugin !2377
  * Honour soft links target in SFTP !2379
  * Optional close confirmation !2380
  * Fix some build warnings !2382
  * Fix manpages !2378
  * Snap cleanup + kwallet support !2381
  * Deprecations and amend g_date_time_format_iso8601 !2383
  * Fixes to snap build !2384
  * Removing dependencies that are available as extensions !2385
  * FreeRDP_OffscreenSupportLevel is of type UINT32 !2386
  * Minor fixes !2387
  * Get the right value for FreeRDP_AutoReconnectMaxRetries !2388
* Thu Feb 10 2022 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.24
  * Contribution section added to issue template
  * Language of VNC encoding cleaned up
  * Remmina Hardening and Compliance
  * Remmina_preferences language reworked
  * Thanks 2021
  * Resolve "Follow-up from "Remmina_preferences language reworked""
  * Encryption level language reworked
  * Issue 2122 : Confirm on close of window
  * Adding flush and cairo clean up
* Mon Dec 20 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.23
  * Patch for a Remmina segfault and stats code cleaning !2358
  * Make Appindicator optional !2359
  * Added check-box to force tight encoding for VNC connections !2360
  * remote resolution: use multiple of four !2353
  * Add Keyboard mapping per client RDP !2361
  * Improve TLS error message, fixes #2364 (closed) !2362
  * Triage policy language reworked !2363
* Mon Dec 13 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.22
  * Fix crash if main window is closed #1692 (closed) !2330
  * Main window position reset after opening a connection (issue 2587) !2331
  * File Interface refactoring !2332
  * CMake refactoring and build time warnings !2333
  * Add Croatian language to desktop shortcuts and infos !2334
  * Appdata corrections and renewal !2336
  * Fixes for freerdp3 compatibility. !2337
  * X2Go: Rewrite dialog-system; Ask users which session to resume... !2328
  * int main(): print instructions how to enable a more verbose output of remmina !2338
  * Mitigations for #2635 (closed) (default printer) with freerdp < 3 !2343
  * X2Go: Add a session-terminate button into the session resuming selection menu !2339
  * Properly warn users when using a plugin which requires GtkSocket !2340
  * x2go_plugin.c: Make changes to source strings for translations. !2344
  * Fix ubuntu-impish-amd64 build errors. !2345
  * Hopefully fix Ubuntu Impish Build !2347
  * Fix string format !2348
  * 2634-ssh-opening-command !2342
  * New debug strings reworked !2341
  * Deduplicated "Started PyHoca" string !2346
  * Removing the Remmina stats sender and repurposing Remmina stats !2350
  * X2Go: Major rewrite of session-terminating system. !2349
  * Message about debugging info reworked !2351
  * Strings in rcw.c reworked !2352
  * VNC custom encodings to avoid corrupted frames. !2354
  * X2Go format string bugs !2355
* Mon Oct 18 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Updated to remmina version 1.4.21
  * Nullify host if qucikconnect isn't a valid address
  * rdp_plugin.c: Fix dereferencing of NULL variable when profile name is empty
  * Resolve label spacing in preferences window
  * GNOME 40 runtime and other updates
  * Add support for ESX web console login
  * Added RDP general option to remap scancodes
  * Back compatibility with WebKit < 2.32.0
  * Make screenshot file names iso8601 compliant
  * Typo in bug-report template
  * Typo in merge-request template
  * Implementing restricted-mode and password hash
  * Unitialized var by @qarmin (Rafał Mikrut ). Closes #2594
  * Add integer-only input field for plugin settings in Remmina Editor
  * Adding VNCI Listen port field tooltip
  * Fix the translation problem of "tooltip" in ssh window
  * Rework x2go_plugin.c to comply with remmina coding style.
  * Add validation system for Remmina Editor
  * Small changes to README, AUTHORS and error message adjusting in remmina_file_editor.c
  * remmina_file_editor.c: Readd by mistake removed '!'
  * Mitigation for #1951 and extra RDP clibpoard debug messages
  * Rollback Let's Encrypt SSL workaround
  * Add RDP clipboard support for Microsoft HTML Clipboard Format
  * Building FreeRDP with icu support
  * Resource renaming to comply with the Freedesktop rules
- Package all icons in the main package
- The new x2go packages are not yet packaged, as x2go is not available in the
  openSUSE distributions
* Fri Jul  9 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- the following plug-ins are no longer generated:
  * remmina-plugin-xdmcp
  * remmina-plugin-nx
  * remmina-plugin-st
- Removed obsolete mark-appindicator-as-required.patch
- Update ro remmina 1.4.20
  * Mark appindicator as required !2290
  * Disabling XDMCP, NX, and ST !2291
  * Remove plugins/st,xdmcp,nx for submodule replacement !2292
  * SSH tunnel MFA !2293
  * Adding connection profiles menu into the toolbar !2295
  * Resolve "Preferences buttons not working since v1.4.19" !2296
  * Some X11 related functions cleanup
* Wed Jun 30 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- App-Indicator is now required
- Added upstream mark-appindicator-as-required.patch to see better error messages
  when appindicator is not around
- Update to 1.4.19
  * Fix Freerdp Git Revision !2277
  * UI improvements and cleanup !2278
  * Desktop integration for the Remmina SNAP !2279
  * Add process-control to the remmina snap !2276
  * Adding SSH_AGENT support to the snap package !2280
  * Adding option to disable smooth scrolling !2281
  * Scrolled Viewport: use viewport_motion_handler as the only timeout indicator !2282
  * Adding TCP redirection through rdp2tcp !2283
  * Added setting for RDP number of reconnect attempts !2284
  * Add RDP reconnect interrupt on window close, fix crash introduced with 7c13b918.
    Should fix #2079 (closed) !2286
  * Removing GtkStatusIcon as deprecated !2285
  * Adding advanced option to share multiple folders !2287
  * Profile list grabs the focus when search is hidden !2288
* Fri Jun  4 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 1.4.18
  * Try more shells as launcher if default isn't found !2269
  * Minor fixes for v1.4.17 !2270
  * SSH session improvements !2271
  * Fixes - Auto-start file created on tray icon disabled !2272
  * RDP: Remove older usage of ClientHostname
  * Fix libfreerdp version check
  * Explicitly set user resolution to a multiple of 4
  * Code refactoring - ASAN exceptions !2274
- Fixed remmina-plugin-nx dependencies
* Sat May 22 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 1.4.17
  * Fix build with musl libc
  * Fix typos
  * Improving CI cache
  * Fix System Tray Icon Broken/Missing
  * VNC quality deafults now to good
  * Flatpak refactoring
  * Adding Gateway websocket support
  * Revert "Linking snap and flatpak to FreeRDP 2.3.1"
  * Set FreeRDP config path to Remmina profiles path
- Fixed build-logic for NX, enable per default
- Enable kwallet and appindicator non SLE distributions
* Sun May 16 2021 olaf@aepfle.de
- Rename internal bcond from nx to remmina_nx
- Use cmake_build
- Use bcond for kwallet, which defaults to enabled
- Use bcond for appindicator, which defaults to disabled
  GtkStatusIcon works everywhere, while Appindicator works just in KDE
* Fri May 14 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 1.4.16
  * Fix Data PATH for the FreeRDP files
* Tue May 11 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 1.4.15
  * Fixing SSH plugin colour palette initialization. !2255
* Mon May 10 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to 1.4.14
  * NEW: Experimental VNC plugin using GTK-VNC
  * VNC - Ignore remote Bell option and other fixes !2237
  * Fixing color palette size for themed SSH !2253
  * Bump FreeRDP version to 2.3.2 !2226
  * Fixes search bar shortcuts wrong bahavior
  * Honour theme settings when run from command line
  * FTP UI improvements
  * Config SSH tunnel username takes precedence.
  * Allow groups to be expanded and collapsed by using the keyboard
  * Fixing VNC repeater logic.
  * Send text clipboard content as keystrokes
  * scrolled viewport: explicitly recheck whether the timeout is active
  * Resolve Host+Page_Down triggers search text in SSH
  * UNIX sockets initial support
  * Fixed wrong freerdp_settings function use
  * Fixing RemminaConnectionWindow map/unmap events
  * Spelling: Comma-separated, List monitor IDs
  * Set Remmina specific FreeRDP config data folder
  * Optional port connection instead of server
  * Resolve "Use LZO compression for Snap to improve startup speed"
  * Make wayland not mandatory during compile time
  * Do not use alpha as it is not used for the Desktop
  * Refactoring: Deprecations and warnings
  * Removing unneeded widgets in the headerbar
* Thu Apr  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.13
  * Use freerdp_settings_get|set API
  * rdp: Allow autoreconnect for ERRINFO_GRAPHICS_SUBSYSTEM_FAILED
  * Disable cert file auth when libssh < 0.9.0
  * Removing redundant subtitle
  * Removing redundant ssh_userauth_none
  * Fix build issues on openSUSE
- Drop upstream_build_fixes.patch
* Sun Mar  7 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.12
  * New features:
  - Multi-monitor support !2184 (merged) @antenore
  - Adding SSH certificate authentication !2208 (merged) @antenore
  * Improvements
  - Improved spelling, fixed typos
  - Some refactoring and fixes for 1.4.11 !2198 (merged) @antenore
  - Revert "rdp/event: Fix wheel value for GDK_SCROLL_DOWN events"
    !2199 (merged) @pnowack
  - Resolve "Left-handed mouse support" !2200 (merged) @antenore
  - Rafactoring: GResource based UI elements !2201 (merged) @antenore
  - Refactoring SSH themes !2205 (merged) @antenore
  - Removing legacy audio settings !2207 (merged) @antenore
  - Refactoring SSH tunnel authentication. #2414 (closed) !2211 (merged) @antenore
  - Improve pre-connection FreeRDP channel initializations !2212 (merged) @antenore
  * Fixes
  - Invalid connection option ":port" removed !2193 (merged) @kingu
  - Add ifdefs for SPICE version less then 0.38
    (fix #2408 (closed)) !2195 (merged) @hadogenes
  - Fix for #2408 (closed) building with older SPICE libraries
    !2194 (merged) @jweberhofer
  - Ignoring GLib functions if on versions older than 2.56 !2196 (merged) @antenore
  - Fixing compiler errors related to Python plugin support on master
    !2178 (merged) @ToolsDevler
  - Fixes for multi-monitor and Weblate !2202 (merged) @antenore
  - Fixing memory leaks and minor bugs !2206 (merged) @antenore
- Added  upstream_build_fixes.patch to fix several build issues on wayland
- Removed patches fix_upstream_2196_older_glib_issue.patch
  and fix_upstream_2195_spice_plugin.patch
* Mon Feb  8 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added fix_upstream_2196_older_glib_issue.patch  to allow building with
  older glib versions
* Sun Feb  7 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added fix_upstream_2195_spice_plugin.patch to allow building on older
  opensuse versions
* Wed Feb  3 2021 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.11
  * New features:
  - Implementing simple SSH multi factor authentication.
    !2162 (merged) @antenore
  - Implementing dynamic resolution in SPICE plugin
    !2150 (merged) @hadogenes
  - Disabling Python support by default !2158 (merged) @antenore
  - Add capability to load Python plugins (not finished).
    !2157 (merged) @ToolsDevler
  * Improvements
  - Suppress Output PDU when the RDP window is not visible
    !2159 (merged) @antenore
  - Several improvements on spelling
  - Command line help improvements !2185 (merged) @antenore
  - Improving error detection !2181 (merged) @antenore
  - Using curly double quotes where possible !2182 (merged) @antenore
  - Refactoring the RCW toolbar to use the right tool items types
    !2188 (merged) @antenore
  * Fixes
  - rdp/cliprdr: Fix header of FormatList message !2147 (merged) @pnowack
  - rdp/event: Fix wheel value for GDK_SCROLL_DOWN events !2149 (merged) @pnowack
  - Resolve "Remmina does not handle file:///some/path/to/file.rdp syntax"
    !2152 (merged) @antenore
  - Resolve "SSH tunneling, honoring ssh_config (User, HostKeyAlias,
    ProxyJump, HostKeyAlgorithms, IdentitiesOnly, etc.)"
    !2154 (merged) @antenore
  - Resolve "While in the main window, bind F10 keyboard shortcut to
    toggling the main menubutton" !2156 (merged) @antenore
  - Refactoring SSH plugin !2160 (merged) @antenore
  - Remove extra parenthesis !2164 (merged) @yurchor
  - Spice option to choose Prefered Video Codec and Image Compressor
    !2165 (merged) @hadogenes
  - Correct iterating lines in string - address sanitizer fix #2390 (closed)
    !2174 (merged) @hadogenes
  - Correct freeing memory in spice !2175 (merged) @hadogenes
  - Issue/2391 randomness !2176 (merged) @antenore
  - Resolve "Missing keyboard shortcuts to toggle search (Ctrl+F, Escape),
    and closing the search doesn't clear the search" !2179 (merged) @antenore
  - Resolve "Always false contition in remmina_ssh.c" !2180 (merged) @antenore
  - Fix minor typo !2186 (merged) @yurchor
  - Resolve "Remmina Crashes when opening the preferences with the accelerator"
    !2189 (merged) @antenore
  - Fixing #2401 (closed) - crash when using ctrl+p !2190 (merged) @antenore
* Fri Dec 11 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.10
  * Resolve "RDP Black Screen on connection" !2123 @antenore
  * Correctly importing and exporting audiocapturemode, closes #2349 !2124 @antenore
  * [RFC] rdp: add Use base credential for RD gateway authentication !2125 @Fantu
  * Resolve "Auto accept changes to fingerprints and auto accept certificates" !2126 @antenore
  * "Fingerprinters" corrected to "fingerprints". !2127 @kingu
  * Implementing network type option !2128 @antenore
  * Improving the terminal colour file picker !2129 @antenore
  * Resolve "[RDP] Since v1.4.9 Audio is no longer working" !2130 @antenore
  * New connection strings corrected !2131 @kingu
  * Correct location of Terminal colour scheme setting !2132 @kingu
  * Fixing pulseaudio LD_LIBRARY_PATH and staging PA libraries !2136 @antenore
  * [RFC][v2] RDP: Add Use base credential for RD gateway authentication !2135 @Fantu
  * fix incorrect name date log sessions ssh !2137 @acendrou
  * Resolve "Strange padding in main window" !2138 @antenore
  * Remove legacy rfx code !2139 @antenore
  * Resolve "RDP export features does not properly include gatewayhostname" !2140 @antenore
  * RDP log filters keep previous value across connections !2143 @antenore
  * [RFC][v2] RDP: Add Use base credential for RD gateway authentication !2135 @Fantu
  * Emit warning if libkf5wallet missing but required by -DWITH_KF5WALLET=ON !2144 @giox069
  * Do not activate performance optimisations based on network type unless explicitly requested. !2145 @antenore
* Mon Nov 23 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.9
  * Updated color schemes from iTerm2-Color-Schemes
  * Use previously defined DATADIR to install Kiosk files
  * RDP and VNC: Fix smooth scrolling when abs(delta) < 1.0, see issue #2273
  * Alexander Kapshuna added to remmina_about.glade
  * remmina_main_quickconnect: recognize ip when textbox has ip:port in it,
    and strip whitespaces
  * Implementing text search in the SSH plugin
  * Spelling: Plugin manager language reworked
  * Save screenshot_name and use correct seconds format
  * Resolve "Autostart checkbox setting not saved"
  * rdp: document freerdp Performance Flags setted by quality setting
  * Resolve "Terminal general preferences are not saved"
  * Resolve "Typo in FindFREERDP3.cmake"
  * rdp: add freerdp log filters setting
  * Resolve "Extra underline character in "_Preferences" tooptip text"
- Requires pcre2-devel
* Fri Sep 11 2020 Yifan Jiang <yfjiang@suse.com>
- Build with kwallet and libappindicator on Tumbleweed, Leap and
  SLE releases greater than SLE-15-SP2 (jsc#SLE-11656).
* Fri Aug 14 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.8
  * Adding timout option for RDP connections.
  * Avoid quickconnect to empty hostnames. Fixes #2240
  * Using full paths instead of variables
  * Add support for quick connecting to RDP, VNC and SPICE from the
    command line
  * Add SSH support to the protocol handler
  * Restart SSH session when user has provided new username or password to
    allow for changing SSH user
  * Use inline with AppStream 0.12 specification.
  * Enabled GDK_SCROLL_SMOOTH for RDP/VNC
  * Some fixes for the RDP backend
  * Trim white from ip addresses input into quick connect bar
  * Enhancing the SNAP info dialog box
  * Adding FreeRDP log level setting
* Fri Jul  3 2020 ecsos <ecsos@opensuse.org>
- Set minimal freerdp version to 2.1.0, because with 2.0.0
  Remmina can not build.
* Wed Jun 24 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.7 (boo#1173296)
  * Allow compilation with libwinpr (FreeRDP) pre commit 8c5d96784d !2083 @giox069
  * Bugfixing v1.4.6 !2082 @antenore
  * Spelling: Automatic negotiation !2084 @kingu
  * Spelling: GNOME Shell, opt-in desc, comments !2085 @kingu
  * Memory leak fixes !2086 @antenore and @giox069
  * RDP: Replacing deprecated FreeRDP function VeryfyCertificate !2087 @antenore
* Tue Jun  9 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.6
  * Hotkey language fixed
  * Fetch news from remmina.org optional
  * allow saving notes in connection profile
  * RDP: Improving hardware option parsing
  * Rearranged widgets in a new Behavior tab
  * Add separator only when there are saved profiles. Fixes #1914
  * Implementing resume all for FTP file transfer, should fix #2210
  * Edit or connect using multiple profile files from the command line
  * Desktop session files for Remmina kiosk are optional
  * Spelling fixes
  * Translation fixes/improvements
  * Feat/lebowski
- Disabled news
- Enabled kiosk sessions
* Mon May 25 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.5
  * SSH plugin - adding font resize - closes #2201 (closed) !2059 (merged) @antenore
  * Fixing keyboard grabbing issues with screenshot tool !2062 (merged) @giox069
  * Refactoring remmina_debug to avoid memory leaks and overhead, should fix #2202 (closed) !2061 (merged) @antenore
  * Using directory only to expose artifacts !2060 (merged) @antenore
- removed remmina-bug-2061.patch now integrated in upstream
* Fri May 22 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.4
  * RDP Plugin - Adding UDP support, implements #2153 !2038 @antenore;
  * Adding proxy and local storage support !2039 @antenore;
  * RDP option to prefer IPv6 AAAA record over IPv4 A records !2040 @antenore;
  * Allow users to override the app ID !2044 @garymoon;
  * Use icon name instead of localizable string in gtk_image_new_from_icon_name() !2045 @yurchor;
  * Fix minor typos !2046 @yurchor;
  * Don't grab when window has no focus, issue #2165 !2047 @giox069;
  * SSH tunnel and VNC fixes !2048 @antenore;
  * Adding explicitly trueColour in the client format structure. Fixes #2181 and #810 !2049 @antenore;
  * Code refactoring. !2050 @antenore;
  * Extract subtitle for translation !2051 @yurchor;
  * [SSH] Connection pre/post command not replacing SSH tunnel parameters !2053 @antenore;
  * SNAP: Remove libssh, available in distro !2052 @ed10vi;
  * Create floating toolbar when ftb is set to off, 2189 !2054 @giox069;
  * Adding Remmina_debug function to simplify log reporting !2055 @antenore;
  * Removing OnlyShowIn as deprecated in the latest freedesktop spec. Closes #2198 !2056 @antenore;
  * Cleaning up GLib deprecations !2058 @antenore;
  * And much more committed directly in the master branch;
  * Polish is a new language.
  * Thousands of new strings have been translated with Weblate;
- added remmina-bug-2061.patch to fix for build issue in remmina issue #2202
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add '-fPIC' on aarch64 to fix build
* Thu Apr 16 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.3
  * KB grabbing fixes (mostly for Wayland)
  * Adding Freerdp 3 compile option and using FreeRDP tag 2.0.0 as default
  * Adding remmina terminal dependencies
  * Updated translations
* Thu Apr  9 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.2
  * Bug-fixing release related to SSH bugs
  * Adds ClientBuild settings to RDP plugin to specify client version build number
  * Spelling: Smaller bullet points, RDP plugin
  * Allow formatting for SSH session filename
  * web-browser plugin fixes
  * Make duplicate session sensitive only if a profile exists
  * Issue template reworked
  * Fix null pointer dereference in remmina_main_quickconnect
  * SFTP with tunnel fixes
  * Cppcheck and PVS Studio Fixes
  * VNCI fixes
  * Typo fix in remmina_ssh.c
  * Allow enter key in domain textbox of authentication dialog to submit
  * rcw event sources cleanup (bsc#1169412)
* Tue Feb 25 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to release 1.4.1
  * Bug-fix release
  * SSH fixes, should fix #2094
  * Update remmina_filezilla_sftp.sh
* Fri Feb 21 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.4.0
  * This is a long term release
  * RDP clipboard fixes
  * SSH authentication fixes
  * Fixed compiler warnings
  * SSH tunnel refactoring
  * Parameters passed individually, notation, "Press any key to continue…"
  * Updated boolean expressions
  * Add end of options escaping
  * Remove double-quotes escaping early
  * Ending code block whitespace line removed
  * Safer removal of build directory
  * Spelling: Could not access the RDP server x7
  * Removing double struct declaration
* Wed Jan  8 2020 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.10 (jsc#SLE-9612)
  * VNC: Fix a buffer overflow during cuttext
  * Fix KB/pointer grabbing again and add warning when GTK is using
  * GDK_CORE_DEVICE_EVENTS refactoring
  * Proxy support fixes
- Update to new upstream release 1.3.9
  * Fixing Keyboard grab issues. (mainly within i3wm and XFCE).
* Fri Dec 20 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.8
  * Avoid clearing username/domain when saving RDP password
  * Make Remmina news dialog modal to the main window
  * Change switch notebook page idle func order.
  * Fixing bad seat grabbing behaviour (grab all keys not working)
  * Adding cmake option to use latest FreeRDP symbols when compiling.
  * Adding default application symbolic icons
  * Several translation fixes
- Removed obsolete remmina-1.3.7-libfreerdp-2.0.0-rc4.patch
* Fri Dec  6 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Added remmina-1.3.7-libfreerdp-2.0.0-rc4.patch to be compatibile with
  libfreerdp-2.0.0-rc4
- Update to new upstream release 1.3.7
  * Huge improvements in translations
  * Better authentication MessagePanel API
  * Adding hidden proxy/socks settings for the RDP plugin
  * Debian Lintian, appstream and AppImage detected issues fixes
  * Tooltips in the remmina profile editor
  * Fix for issue #1949 (and #1968). It also relocates --version and --full-version in local istance.
  * Enumerate and share all local printers.
  * Manually specify more then one printer&driver when connecting via RDP
  * Printer sharing remediation
  * Remove useless includes
  * VTE is a suggested package
  * AppImage path fixes
  * Using remmina image for gnome 3.28
  * Fix crash when clicking AR-button
  * Various Fixes !1931
  * Fix RDP failed auth after credentials panel: big rework on plugin connection close flow
* Tue Aug 27 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.6
  * Fix fullscreen switching
  * Fullscreen fixes
  * rdpr channel initialization for special devices sharing. Closes #1955
  * Fixing remminamain destroy issues
  * Makes Rmnews modal to avoid that it steals input to the RCW
  * Make some cmake targets optional to avoid packaging isssues
  * SNAP fixing dependencies for the plugin WWW
  * Updating Remmna icon to the yaru/suru icon set.
  * Adding harfbuzz headers, closes #1941
  * New stats
  * *.md: typo corrections
  * Remove G+ from documents
* Mon Aug  5 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Removed dependency to NX for remmina-plugin-kwallet.
* Wed Jul 31 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.5
  * Configurable, human readable profile file names
  * A KDE Wallte plugin, that can be used instead of the GNOME Keyring
  * Many notable and subtle bugs fixed by Giovanni Panozzo.
  * Null pointer reference, RDP issues, remmina connection window fixes and refactoring and many more!!
  * Remmina news (and announcements) widget
  * Periodically (sporadically) a widget will be shown with news and announcements related to your Remmina version.
  * Master password, to protect settings and profiles from unauthorized modifications
  * WWW plugin (web browser with authentication for Remmina)
  * New color schemes for the SSH plugin.
  * Preferences cleaning
  * Profile saving bug fixed
  * Remmina main UI improvements
  * Typographic and wording corrections
- Removed broken telepathy plugin
- New kwallet plugin will be built only on openSUSE and SLE backport
  releases.
* Wed Mar 13 2019 Felix Zhang <fezhang@suse.com>
- Update to new upstream release 1.3.4
  * Updated to use core18 and gnome-3-28-1804 !1797
  * Snap: Build snap in CI and publish to the edge channel for
    builds against master !1810
  * Resolve "SSH public key cannot be imported: Access denied for
    'none'. Authentication that can continie: publickey" !1811
  * snap: Ensure the icon is installed !1812
* Thu Feb 28 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.3
  * Fix “Utranslated” typo + XHTML 1.0 strictness + move div CSS rule in style block
  * Revert autoclosed <script> tags. It seems to be badly surported
  * Remmina connection window refactoring
  * Adding Serial and parallel ports sharing
  * RemminaMain window refactoring - Removing deprecated functions.
  * Fix #1836 implementing the correct message panel when authenticating
  * Make ssh tunnel pwd user manageable and public key import
  * Fix Yes/No inversion
  * Updated translations: de, zh_CN, it, fr, tr, da, it
* Fri Feb  1 2019 jweberhofer@weberhofer.at
- Upgraded to 1.3.2 (boo#1123452, boo#1103557)
  * Change rcw size allocation wait algorithm, see issue #1809
  * Fix a couple of VNCI crashes, see issue #1821
  * Fix spice authentication, issue #1820
  * Update translations script fixes
  * Add a missing end point in an SSH error message
  * Translation Updates: fr, it
  * Cosmetic fixes
* Tue Jan 29 2019 jweberhofer@weberhofer.at
- Removed upstream patch remmina-1.3.0-removed-edit-delete.patch
- Upgraded to 1.3.1
  * fixed several typograpic errors
  * fixed VNC clipboard bug
  * Translations updated: en, de, tr, ru, it, es
  * Translations for SSH error messages
  * Performance improvement
  * Improved CSS Styles
  * rcw fixes
  * fix scrolling in fullscreen mode
  * fixed several issues
* Tue Jan 22 2019 jweberhofer@weberhofer.at
- Added remmina-1.3.0-removed-edit-delete.patch from upstream to
  exclude edit-delete.svg causing a conflict with kaffeine.
* Fri Jan 18 2019 jweberhofer@weberhofer.at
- Upgraded to 1.3.0
  * Use window resolution
  * rcw_preopen complete
  * RDP: new global parameter rdp_map_keycode
  * Use decimal instead of hex on rdp keycode map
  * Updated translations
  * Adding language detection
  * Auth panel widget placement
  * CSS modifications to adapt to stock Gnome and Gtk themes
  * Updated CSS to have black background in fullscreen
  * Gtk deprecation and CSS restzling
  * Gtk icon cache update during install phase
  * Correctly set focus after rcw_preopen
  * Icons and gtk fixes for rcw_reopen
  * Deprecates dynamic_resolution_width and height cfg params
  * Disable glyph cache by default
  * Fix crash when showing password panel
  * Fix crash when showing password panel
  * allow closing tab after error message panel is shown
  * Remove deprecated floating toolbar toplevel window
  * Fixed missing icons
  * Make menu items paintable by the application
  * Open connection window before connecting
  * Prevent toolbar signals while reconfiguring toolbar
  * Update toolbar button handling
  * Added xrdp friendly options, the "Relax Order Checks" and
    "Glyph Cache" options  are required for connections to xrdp
    servers (boo#1125549, boo#1129319)
  * RDP fixes: remove redundant rfi->width/rfi->height and more
  * RDP: correctly destroy rfi->surface during a desktop resize
  * RDP: move gdi_resize() to a better place
  * RDP: remove unneeded OrderSupport struct init
  * VNC: Fix possible crash during connection
  * Search box clear icon
  * Updated CONTIBUTING.md and README.md
  * Updated sponsor list
  * Updated wiki URLs
  * Updating coyright for year 2019
* Tue Nov 20 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.32.1
  * Add desktop-gnome-platform and fix themes in SNAP
  * Implement smartcard name setting
  * man+help: elaborate on file types of -connect and -edit cmd line options
  * RDP: add FREERDP_ERROR_SERVER_DENIED_CONNECTION message
  * Removing X11Forwarding code as it is wrong and causing issues
  * Updated turkish translation
* Sun Oct  7 2018 jweberhofer@weberhofer.at
- new plugin remmina-plugin-st (simple terminal)
- Upgraded to 1.2.32
  * Avoid to save last_success property if stats are not enabled.
  * GW auth data was saved in the server auth data.
  * Do not register socket plugins when X11 is not available.
  * Screenshot enhancements.
  * RDP GW authentication.
  * Adding global preference for search bar visibility.
  * Allow wayland backend again when GTK >= 3.22.27.
  * Added turkish translation.
  * Add option to honour https_proxy and http_proxy environment variable.
  * Force program name to app id.
  * Printing builds flags with remmina --full-version command option.
  * Fix KB grabbing when switching workspace.
  * Dealing correcthly with some deprecations, getting rid of most
    of G_GNUC_BEGIN_IGNORE_DEPRECATIONS.
  * Improving file type hadling.
  * Adding error check on remmina_pref_save.
  * Many bug fixing as usual.
* Mon Aug 27 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.31.4
  * Enhancements
  - Improving file type hadling.
  * Fixed bugs
  - Fix KB grabbing when switching workspace.
  - Fix some possible crashes when reading a remminafile.
  - Fixes a crash deleting XDMCP profile.
  - Fixing libssh deprecations.
- Upgraded to 1.2.31.3
  * Enhancements
  - Implement send ctrl+alt+fn keys.
  * Fixed bugs
  - Do not send stats if the remmina.pref file is read.
  - cmake: include libssh_threads only when available.
  - Set program class to REMMINA_APP_ID
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrasing in summary.
* Wed Aug  8 2018 jweberhofer@weberhofer.at
- New package remmina-kiosk is now available
- Upgraded to 1.2.31.2
  * Fixed bugs
  - Cannot minimize in fullscreen mode.
  - Crash with the RDP plugin.
  - Missing manual pages
- Upgraded to 1.2.31
  * Notables changes
  - Custom color schemes per profile for the SSH plugin
  - Flatpak updates and fixes
  - Kiosk mode with integration in the login manager
  - New Icons
  - SFTP tool password fixes
  - Several fixes around RDP and compilations issues (bsc#1117402)
* Tue May 29 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.30.1
  * Enhancements:
  - Move search bar below the header bar #1648
  - Failure to link with lld on OpenBSD #1604
  - Add search toggle #1653 (antenore)
  - Move search bar below the header. #1649 (antenore)
  * Fixed bugs:
  - RDP - Remmina process dies after entering password and clicking "OK" #1643
  - Fixing segmentation fault due to setting name NULL #1650 (antenore)
* Mon May 21 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.30
  * Enhancements:
  - HiDPI - Elements spacing in the headerbar is too low #1628
  - Failure to link with lld on OpenBSD #1604
  - RDP - Implement xfreerdp like --no-fastpath option #1596
  - 'remmina -c' accepting only configs with .remmina extension. #1454
  - [Feature Request] Add SPICE Native WebDAV shared folder support #1273
  - Register and support opening rdp files directly #1105
  - Panel Icon almost invisible #1006
  - Rename UNIQUE_APPNAME to REMMINA_APP_ID and use it wherever possible #1637 (larchunix)
  - Update new logo from Ura Design #1636 (antenore)
  - Increase headerbar elements spacing #1629 (antenore)
  - Support for "gatewayaccesstoken" (aka PAA) and "authentication level" RDP file properties #1621 (p-pautov)
  - Autodetect missing H264 on libfreerdp #1617 (giox069)
  - Project folder refactoring following the GNOME guidelines. 2nd batch. #1600 (antenore)
  - RDP: option to disable fast-path, fixes #1596 #1597 (giox069)
  - Term enhance - Color scheme import #1585 (antenore)
  * Fixed bugs:
  - Assert in remmina_pref_save #1570
  - Minor graphical issue on Ubuntu 18.04 with communitheme #1546
  - Security Bug: Unchecked call to gcry_control #830
  - "Floating point exception" while connecting to Windows 10 machine #681
  * Closed issues:
  - undefined symbol: vte_terminal_copy_clipboard_format #1591
  - RDP: Dynamic resolution updates don't work anymore after updating freerdp from 2.0.0_rc1 -> 2.0.0_rc2 #1576
  - Statrtup issues remmina / gnome / wayland / opensuse leap 15 beta #1558
  - VNCI connection not working! #1502
  - Highlight to copy - SSH #1434
  - Password not saving - encrypting *.remmina connection files #1423
  - Remmina crashes when sharing local printers and connecting through gateway #1405
  - Remmina lock screen when i use it to connect to Win10. #1396
  - Windows 10 BSOD on file copy #1019
  - ALT + F4 closes Remina remote Window #125
  * Merged pull requests:
  - Update italian translation #1631 (giox069)
  - Updated French po file #1630 (DevDef)
  - Write newline instead of return #1626 (weberhofer)
  - Updated German Translation #1624 (weberhofer)
  - Fix libssh deprecations in NX plugin #1613 (larchunix)
  - Headerbar spacing fixes #1607 (antenore)
  - Place headerbar in the main container. Fixes #1546 #1606 (antenore)
  - File list and indicator icon optimizations #1603 (giox069)
  - Project folder refactoring following the GNOME guidelines.
  - SPICE: add support for ssh tunnelling #1595 (larchunix)
  - Clang LLVM coverage flags #1594 (antenore)
  - GTK deprecation fixes #1592 (larchunix)
  - Undo commit 5b4e7f1 and change VNCI plugin description #1586 (giox069)
  - Fix a bunch of warnings #1583 (larchunix)
  - build: make appindicator include consistent with pkg-config flags #1582 (larchunix)
  - Add openSUSE info and instructions to README #1581 (jubalh)
  - Libssh has removed red.libssh.org #1574 (antenore)
  - periodic_usage_stats_uuid_prefix default value #1572 (antenore)
  - Use string constant #1569 (amtlib-dot-dll)
  - CMake cleanup #1568 (larchunix)
* Mon Apr  9 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.28
  * Update Czech translation #1555 (AsciiWolf)
  * Switch back to x11 GTK backend under Wayland #1554 (giox069)
  * TCP_USER_TIMEOUT is in milliseconds #1553 (antenore)
  * Disable VNCI plugin #1550 (giox069)
  * Fix typo #1549 (mfvescovi)
  * Missing secret plugin handling #1548 (giox069)
  * Fixes for rcgit-28 #1547 (antenore)
* Wed Apr  4 2018 jweberhofer@weberhofer.at
- Desktop and icon updates will only be executed on suse
  versions prior to 1500.
* Wed Apr  4 2018 jweberhofer@weberhofer.at
- Activated telepathy plugin
- Enabled PIE
- Removed 644cd140a387c7b5d3805b8af9554e241d5d2954.patch: included
  in upstream
- Upgraded to 1.2.0-rcgit.28
  Implemented enhancements:
  * window has no focus when open ssh sessions #1530
  * Enhancement - Variables for pre- and post-commands #1485
  * Register and support opening rdp files -
    Mime improvements #1497 (antenore)
  * Profile and group name niddles in the pre/post
    commands #1492 (antenore)
  * Add xdmcp protocol to Keywords #1491 (mfvescovi)
  Fixed bugs:
  * Remmina fails to connect to SSH server without
    compression since 1.2.0-rcgit-27 (git rcgit-27) #1505
  * Pasting something that was copied in another VM that
    has since been closed causes crash #1484
  * SSH password authentication failed Wrong state
    during pending SSH call #1428
  * Fix clipboard cleanup, fixes issue #1484 #1486 (giox069)
  * telepathy: add dbus-glib-1 to link flags
  * Minor improvements on secure plugin and SNAP welcome message #1545
  * Fixes segmentation fault reported by #1499 #1503
  Other improvements:
  * Redesign - Removed icons where not needed #1535
  * Delay and use gtk_window_present_with_time() #1533
  * Update French translation #1524
  * Fixes for fedora bugs - desktop file and AppStream metadata #1523
  * Desktop data fixes #1522
  * Updated Hungarian translation #1517
  * Removed compression option as not compatible with all SSH servers #1506
* Fri Feb 16 2018 jweberhofer@weberhofer.at
- Add 644cd140a387c7b5d3805b8af9554e241d5d2954.patch: Fix
  compilation on factory (gh#FreeRDP/Remmina#1476)
* Thu Feb 15 2018 jweberhofer@weberhofer.at
- Updated dependencies
- Upgraded to 1.2.0-rcgit.27
  Implemented enhancements:
  * Remmina usage statistics collection
  * Remmina stats: Profiles and protocols counter
  * Updated freerdp on flatpak definition file
  Fixed bugs:
  * RDP + DYNRES: Screen is black immediately after connection and becames
    visible only later when DISP_DVC_CHANNEL_NAME is connected
  Other improvements:
  * Add initial [MS-RDPEGFX] software support
  * Permit SCALE_MODE_DYNRES before DISP_DVC_CHANNEL_NAME is enabled.
* Fri Jan  5 2018 jweberhofer@weberhofer.at
- Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugin-secret'
- Added remmina-plugin-exec which allows execution of local commands
- Upgraded to 1.2.0-rcgit.26
  Implemented enhancements:
  * Allow external commands without protocols in create connection dialog
  * Option to completely hide the floating toolbar when in fullscreen.
  * Option to run Pre Command before ANYTHING else
  * Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugins-secret'
  * Variables for pre- and post-commands
  * Implement an exec protocol plugin
  * Add SPICE Native WebDAV shared folder support
  * Added encryption algorithms options for SSH
  * SSH tunnel and pre/post commands improvements
  * Prior commands improvements
  * Add avahi host discovery for ssh and sftp plugins
  Fixed bugs:
  * Un-check of "Fullscreen on the same monitor as the connection window" won't save
  * Remmina resets screen resolution settings in RDP shortcut
  * SSH Tunneling is broken with SSH Agent with public key
  * Align SFTP and SSH plugins authentication and tunnel functionalities.
  * ssh_userauth_publickey_auto: should accept empty passphrase
  * Un-check of 'Fullscreen on the same monitor'
  Other improvements:
  * Updated translations
  * Fixed typos
  * Remove a couple of legacy "resolution" fields
* Thu Oct 26 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.24
  Implemented enhancements:
  * Save SSH session to file
  * snap: Use the new desktop, desktop-legacy and wayland interfaces
  * snap: add password-manager-service interface for gnome-keyring
  * vte no longer optional
  * Fix window state saving for remmina_connection_window and main window
  * Crashes when I try opening Preference
  * Resolution and Passwords Not Saving in Connection Profiles
  * Focus-out-event should call UNFOCUS plugin feature, fixes
  * Fix some memory leaks
- Bugfixes
* Thu Oct 12 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.21
  Implemented enhancements:
  * Feature Request: Create custom Terminal Color Schemes for SSH #1235
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Feature request - Option - Floating Desktop Name [$5] #815
  * Don't close connection windows when main window is closed #785
  * File association for connections #485
  * Implementation of dynamic resolution update for RDP #1292 (giox069)
  * Shortcutkey viewonly #1289 (antenore)
  * Simplify pthreads library detection #1274 (jabl)
  * Custom Color schemes for SSH #1272 (antenore)
  * RDP client keyboard mapping with GTK3 #1265 (giox069)
  * Make building the VNC plugin optional #1263 (diogocp)
  Fixed bugs:
  * copy / paste and charset #1300
  * Changes user name ssh tunnel (vnc over ssh) do not save. #1255
  * SSH username ignored for Tunnels for RDP #1254
  * Can't Specify X :display for XDMCP. #1251
  * "Remember last view mode for each connection" not respected in v1.2.0-rcgit.19 #1247
  * Remmina always remember password #1224
  * Host key not working with SPICE plugin connected to KVM client. #1035
  * Shortcutkey viewonly #1289 (antenore)
  Merged pull requests:
  * Fix charset conversion in VNC clipboard #1303 (giox069)
  * Add support for application/x-remmina MIME type, fixes #485 #1299 (giox069)
  * Reverted the notfication for the floating toolbar #1297 (antenore)
  * Fixes for notifications #1294 (giox069)
  * Server name is notified to the user everytime we enter a tab #1290 (antenore)
  * Exit strategy for Gnome Shell 3.26 #1287 (giox069)
  * Fix gtk redrawing in RDP plugin #1286 (giox069)
  * Gtk deprecations #1285 (giox069)
  * Add Keywords entry #1277 (mfvescovi)
  * Runtime paths for AppImage #1271 (giox069)
  * Get ssh_username from remmina profile - fixes #1255 #1267 (antenore)
  * Better button labelling and new save button #1250 (antenore)
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Enhancements to upgrade to the new freerdp package
- Removed build dependency: pkgconfig(webkit2gtk-4.0)
- Added new build dependency: libappindicator3-devel
- Built-dependency freerdp2-devel and dependency to libfreerdp2 has been
  introduced to force switching to the new freerdp2 package
- Suggest installation of RDP and VNC plugins
- Don't include app-indicator on SLES
- Cleaned up spec
- Upgraded to 1.2.0-rcgit.20
  Implemented enhancements:
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Set Linux as the default terminal color scheme. Fixes #1238 #1243 (antenore)
  Fixed bugs:
  * Remmina crashes each time I use FTP transfer #1257
  * Problems with some color schemes #1225
  Closed issues:
  * Color on SSH terminal window being applied #1238
  * Tray applet closing when last window gets closed #1236
  * Systray icon closes when closing 'Main Window' or RDP connection #1229
  * SSH Tunneling is broken with SSH Agent with public key #1228
  * Missing icons after compiling latest Git release #1221
  * RDP quality settings not saved #1216
  * Cannot connect after upgrading Ubuntu to 16.04 #946
  Merged pull requests:
  * passphrase not yet used in sftp connection - closes #1257 #1259 (antenore)
  * Added ssh_agent in the list of authorized method, fixes #1228 #1246 (antenore)
  * Connect when pressing enter in the password field #1242 (antenore)
  * Fixed terminal color palettes #1240 (antenore)
  * French translation update and other po files update with new strings to be translated #1239 (DevDef)
  * SSH Kerberos GSSAPI Auth #1237 (giox069)
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus - #1233 #1234 (erichoog)
  * Fix link for issue #367 #1232 (erichoog)
  * Change Status Icon availability for gnome 3.16 #1230 (giox069)
- Upgraded to 1.2.0-rcgit.19
  Implemented enhancements:
  * SSH tunneling does not work with RDP server redirection #1175
  * Enhancement - Another User connected to the server, forcing [...] pop-up #1141
  * RD Gateway Doesn't Support different username/password #933
  * the checkbox, 'Save SSH Password', greyed out. #708
  * RD Gateway authentication doesn't work #511
  * Allow the user to hide the toolbar inside a remmina connection window #413
  * Support for RDP Gateway #347
  * Ssh improvements #1196 (antenore)
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  * RDP: remove server hostname DNS check #1190 (giox069)
  * Pressing Enter in the Domain entry of Auth dialog submits #1163 (iivorait)
  * Add server name to popup warning #1142 (antenore)
  * Add an option to completely disable the floating toolbar in fullscreen mode #1135 (transistor1)
  * The host key should not affect subsequent key operations #1132 (nanxiongchao)
  Fixed bugs:
  * Remmina profile editor scrolling is broken #1179
  * Graphical issues when using byobu/tmux #1151
  * I always got an error message "SSH public key has changed!" #1129
  * problem with tui interfaces in remmina #1076
  * test bounty source #1048
  * Importing rdp file not successful #1039
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  Closed issues:
  * RDP to Win10 makes ToolBar clear #1209
  * Upgrading to 1.2 failed #1202
  * Multiple NICs #1188
  * "Public Key (Automatic)" option does not work with ed25519 keys #1187
  * Cannot connect to Windows 10 after Creators Update (1703) #1186
  * Crashing on Load: Segfault #1185
  * Files in mounted sharefolders become terrabytes big. #1174
  * compilation on Debian 9 #1165
  * Clipboard sync is not working #1164
  * File Transfers to Share Folder Crashing Remmina 1.2.0-rcgit-18 Each Try #1159
  * Segfault when using the host SMB sharefolder on Windows (from Linux client) #1157
  * Custom RDP settings? #1146
  * Missing icons in remote session toolbar #1136
  * Opacity for pop up tool bar is too see-through #1131
  * option to remove fullscreen toolbar completely #1128
  * SSH terminal doesn't work #1125
  * Start remmina with fixed language #1119
  * Remmina Next is Corrupting the Unity Desktop #1111
  * Remove systemd dependency #1100
  * Keyboard Events #1096
  * No move or resize terminal window #1087
  * Connection Timeout - vfprintf.c no such file or directory - Segfault #1080
  * SSH password can't save , terminal auto disconnection #1078
  * Remmina getting down when used ssh & mc #1075
  * Only stored passwords when connecting via RD-Gateway #922
  * VNC over SSH tunnel very slow #713
  * Domain/Username/Password database #711
  * Remmina RDP hangs after second certificate confirmation when using RD gateway #706
  * SSH agent forwarding, tunnels and other nice stuff #692
  * When I open a RDP connexion on Microsoft Windows PC, SSH Client display is messing #663
  * Remmina doesn't respect ssh config files... #235
  * SSH: missed check availability of PubkicKey Auth on remote host before asking passphrase #176
  Merged pull requests:
  * Fixes for the exit strategy #1219 (giox069)
  * Issues 785 966 #1214 (giox069)
  * Ssh protocol plugin implementation #1206 (antenore)
  * The multi password changer #1203 (giox069)
  * Fix snap issues #1200 (dfiloni)
  * Terminal functionalities to make Remmina behave correctly with ncurses #1198 (antenore)
  * Fix multiple typos of 'transfered' word #1173 (mfvescovi)
  * RDP plugin: add password expired message and update po files #1170 (giox069)
  * Remmina --full-version command line option #1169 (antenore)
  * snapcraft: use snap-preload to get dynamic access to /snap path #1161 (3v1n0)
  * Inproved CodeTriage and Bountysource buttons #1143 (weberhofer)
  * Cmake clean #1140 (antenore)
  * Give precedence to libfreerdp2 and winpr2 libs #1138 (antenore)
  * travis: build the snap for PRs in Debug mode #1130 (3v1n0)
  * snap: optionally push all the built snaps on PRs to transfer.sh #1126 (3v1n0)
  * Small English nit (fullscreen_on_auto) #1124 (lnicola)
  * Fix german translation #1120 (giox069)
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(unique-1.0) BuildRequires.
* Fri May 12 2017 tchvatal@suse.com
- Version update to version 1.2.0.rcgit.18:
  * Various fixes around, see the upstream Changelog
* Sun Feb  5 2017 mailaender@opensuse.org
- move README.SUSE to https://en.opensuse.org/Remmina
- update to version 1.2.0.rcgit.17
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.2.0.rcgit.13 as freerdp 1.0 isn't available anymore
- dropped patches:
  * remmina-close-ssh-tunnel-on-disconnect.patch
  * remmina-fix-desktop-file.patch
  * remmina-fix-fullscreen-with-multiple-monitors.patch
  * remmina-fix-install-paths.patch
  * remmina-fix-linker-issue.patch
  * remmina-fix-scrolling-in-vnc-plugin.patch
  * remmina-fix-window-resize.patch
  * remmina-gtk-2-22-support.patch
  * remmina-remove-inline-libvncserver.patch
  * remmina-vte-2.91-support.patch
* Tue Oct 13 2015 dimstar@opensuse.org
- openSUSE_Leap 42.1: also apply the patch for vte-2.91.
* Fri Sep  4 2015 dimstar@opensuse.org
- openSUSE Leap 42.1 (suse_version 1315) also has vte-2.91.
* Thu Jan 22 2015 gber@opensuse.org
- amend remmina-fix-install-paths.patch to fix the installation of
  headers (gh#FreeRDP/Remmina#292)
* Tue Oct  7 2014 gber@opensuse.org
- add remmina-vte-2.91-support.patch in order to support building
  against vte-2.91 for openSUSE >= 13.2
- rename README.SuSE to README.SUSE
* Tue Oct  7 2014 dmueller@suse.com
- fix build against Factory
* Sat Mar 23 2013 gber@opensuse.org
- enable TLS-support in VNC plugin (bnc#804320)
- add remmina-fix-scrolling-in-vnc-plugin.patch which fixes
  scrolling in the VNC plugin (backport from upstream git)
- add remmina-close-ssh-tunnel-on-disconnect.patch in order to
  close SSH tunnels on disconnect and avoid freezing (backport from
  upstream git)
- remmina-fix-window-resize.patch which fixes resizing the window
  (backport from upstream git)
- add remmina-fix-fullscreen-with-multiple-monitors.patch which
  fixes fullscreen mode with multiple monitors (backport from
  upstream git)
* Thu Aug 23 2012 gber@opensuse.org
- add missing dependency on gnutls
* Sat Aug 18 2012 gber@opensuse.org
- added remmina-remove-inline-libvncserver.patch in order to remove
  the inline copy of libvncserver (backport from upstream git)
* Mon Apr  2 2012 gber@opensuse.org
- use original tarball name to fix download check
* Mon Apr  2 2012 gber@opensuse.org
- disable the NX plugin by default
* Wed Mar 28 2012 gber@opensuse.org
- added separare patch remmina-fix-install-paths.patch in order to
  fix the installation paths
- specfile cleanup
- removed remmina-plugins-common, now provided by the main package
- split off -lang subpackage
* Wed Mar 21 2012 gankov@opensuse.org
- rewrote spec for using cmake
- merged with remmina-plugins into one source package (upstream
  now diestributes a single tarball with plugins)
- update to version 1.0.0
  + Main program design and functionality:
  * Switch to the CMake build system
  * Refactoring of code style
  * Changing file name convention
  + RDP protocol related:
  * Support for FreeRDP 1.0
  * Support for RemoteFX
  * Support for Network Level Authentication
  * Added certificate validation prompt
- added remmina-fix-linker-issue.patch which fixes a linking issue
  (backport from upstream git)
- added remmina-fix-desktop-file.patch which fixes the installation
  of the .desktop file (backport from upstream git)
- added remmina-gtk-2-22-support.patch in order to build on
  openSUSE 11.4 with GTK 2.22 as upstream requires 2.24+
* Thu Sep 29 2011 gber@opensuse.org
- libunique1 is available on Factory so use it
- do not recommend non-existent remmina-plugins
- add a note about plugins
* Thu Sep 29 2011 gber@opensuse.org
- change the pkgconfig(libssh) dependency to libssh-devel in the
  - devel subpackage
* Thu Sep 22 2011 gber@opensuse.org
- cleanup
  + added license/copyright header
  + improved description/summary
  + use SPDX license abbreviation
  + removed %%clean section
  + use the correct macros to update the icon/desktop file cache in
    %%post/%%postun
  + use pkgconfig symbols unconditionally (this can be handled
    at the project level)
  + removed empty NEWS
* Fri Apr  8 2011 lijewski.stefan@gmail.com
- spec cleanup, prepare to move X11:RemoteDesktop
* Mon Feb  7 2011 gav@qsolution.ru
- Update to version 0.9.3
  + Integrate scrolled window and fullscreen view modes into one button
  + Remove quick connect menu and consolidate the feature with Connection->New
  menu.
* Fri Nov  5 2010 michal.smrz@opensuse.cz
- Update to version 0.8.3
- Edited BuildRequires and Requires to match web pages
* Mon Sep 27 2010 michal.smrz@opensuse.cz
- merge with nilda package created by djs_core <admin@djscore.org>
* Mon Sep 27 2010 prusnak@opensuse.org
- spec cleanup
* Tue Sep 21 2010 lijewski.stefan@gmail.com
- initial package for openSUSE
